@@ -3,29 +3,30 @@
 use std::error::Error;
 use std::fmt;
 
+use crate::error::CryptoAPIError;
+use crate::{read_from_file, write_to_file, Torus};
 use backtrace::Backtrace;
 use colored::Colorize;
-use itertools::izip;
-use serde::{Deserialize, Serialize};
-
-use concrete_core::math::polynomial::PolynomialSize;
+use concrete_commons::dispersion::StandardDev;
+use concrete_commons::numeric::Numeric;
+use concrete_commons::parameters::{CiphertextCount, GlweSize, LweSize, PolynomialSize};
+use concrete_core::crypto::secret::generators::EncryptionRandomGenerator;
 use concrete_core::{
     crypto::{
-        self,
         encoding::PlaintextList,
         glwe::GlweCiphertext,
         lwe::{LweCiphertext, LweList},
-        CiphertextCount, GlweSize, LweSize,
     },
     math::tensor::Tensor,
     math::tensor::{AsMutSlice, AsMutTensor, AsRefSlice, AsRefTensor, IntoTensor},
 };
-use concrete_npe as npe;
 
-use crate::error::CryptoAPIError;
-use crate::{read_from_file, write_to_file, Torus};
-use concrete_commons::{Numeric, StandardDev};
-use concrete_core::math::random::EncryptionRandomGenerator;
+use concrete_core::crypto::bootstrap::Bootstrap;
+
+use concrete_npe as npe;
+use concrete_npe::{ LWE};
+use itertools::izip;
+use serde::{Deserialize, Serialize};
 
 #[cfg(test)]
 mod tests;
@@ -188,7 +189,7 @@ impl VectorLWE {
             .as_slice()
             .to_owned();
         let result = VectorLWE {
-            ciphertexts: LweList::from_container(ct, LweSize(self.dimension + 1)),
+            ciphertexts: LweList::from_container(ct.to_vec(), LweSize(self.dimension + 1)),
             variances: vec![self.variances[n]; 1],
             dimension: self.dimension,
             nb_ciphertexts: 1,
@@ -920,7 +921,7 @@ impl VectorLWE {
         // add the two ciphertexts together
         self.ciphertexts
             .as_mut_tensor()
-            .update_with_wrapping_add(&ct.ciphertexts.as_tensor());
+            .update_with_wrapping_add(ct.ciphertexts.as_tensor());
 
         // get the size of one lwe ciphertext
         let ct_size = self.get_ciphertext_size();
@@ -1068,7 +1069,7 @@ impl VectorLWE {
         // add ciphertexts together
         self.ciphertexts
             .as_mut_tensor()
-            .update_with_wrapping_add(&ct.ciphertexts.as_tensor());
+            .update_with_wrapping_add(ct.ciphertexts.as_tensor());
 
         // correction related to the addition
         for (mut ciphertext, enc1) in izip!(
@@ -1208,7 +1209,7 @@ impl VectorLWE {
         // add ciphertexts together
         self.ciphertexts
             .as_mut_tensor()
-            .update_with_wrapping_add(&ct.ciphertexts.as_tensor());
+            .update_with_wrapping_add(ct.ciphertexts.as_tensor());
 
         // update the Encoder list and variances
         for (self_enc, ct_enc, self_var, ct_var) in izip!(
@@ -1336,7 +1337,7 @@ impl VectorLWE {
         // subtract ciphertexts together
         self.ciphertexts
             .as_mut_tensor()
-            .update_with_wrapping_sub(&ct.ciphertexts.as_tensor());
+            .update_with_wrapping_sub(ct.ciphertexts.as_tensor());
 
         // get the size of one lwe ciphertext
         let ct_size = self.get_ciphertext_size();
@@ -1889,7 +1890,7 @@ impl VectorLWE {
             self.variances.iter()
         ) {
             // calls the NPE to find out the amount of noise after KS
-            *vout = <Torus as npe::LWE>::key_switch(
+            *vout = <Torus as LWE>::key_switch(
                 self.dimension,
                 ksk.level,
                 ksk.base_log,
@@ -1977,7 +1978,7 @@ impl VectorLWE {
     ///
     /// # Argument
     /// * `bsk` - the bootstrapping key
-    /// * `f` - the function to aply
+    /// * `f` - the function to apply
     /// * `encoder_output` - a list of output encoders
     /// * `n` - the index of the ciphertext to bootstrap
     ///
@@ -2078,11 +2079,10 @@ impl VectorLWE {
                 .update_with_scalar_shl(&(self.encoders[n].nb_bit_padding - 1));
 
             // compute the bootstrap
-            crypto::cross::bootstrap(
+            bsk.ciphertexts.bootstrap(
                 &mut result,
                 &LweCiphertext::from_container(ct_clone),
-                &bsk.ciphertexts,
-                &mut accumulator,
+                & accumulator,
             );
         } else {
             // compute the bootstrap
@@ -2092,7 +2092,8 @@ impl VectorLWE {
                 .get_sub(n * (self.get_ciphertext_size())..((n + 1) * (self.get_ciphertext_size())))
                 .into_container();
             let ct = LweCiphertext::from_container(ct_view);
-            crypto::cross::bootstrap(&mut result, &ct, &bsk.ciphertexts, &mut accumulator);
+            bsk.ciphertexts
+                .bootstrap(&mut result, &ct, & accumulator);
         }
 
         // compute the new variance (without the drift)
@@ -2296,28 +2297,25 @@ impl VectorLWE {
             for _i in 0..encoder.nb_bit_precision {
                 message_res.push('o');
             }
-            let noise = npe::nb_bit_from_variance_99(*variance, <Torus as Numeric>::BITS);
+            let noise = npe::nb_bit_from_variance_99(*variance, <Torus as Numeric>::BITS as usize);
             // <Torus as Types>::TORUS_BIT  + (f64::log2(3. * f64::sqrt(*variance))).floor() as usize;
             let mut noise_res: String = "".to_string();
             // nose part
             for _i in 0..noise {
                 noise_res.push('o');
             }
-            if noise > 64 {
-                panic!(
-                    "noise = {} ; {}",
-                    noise,
-                    (f64::log2(3. * f64::sqrt(*variance))).floor()
-                );
-            }
+            assert!(
+                noise <= 64,
+                "noise = {} ; {}",
+                noise,
+                (f64::log2(3. * f64::sqrt(*variance))).floor()
+            );
 
             let nothing = <Torus as Numeric>::BITS
                 - encoder.nb_bit_padding
                 - encoder.nb_bit_precision
                 - noise;
-            if nothing > 64 {
-                panic!("nothing = {} ", nothing,);
-            }
+            assert!(nothing <= 64, "nothing = {} ", nothing);
             let mut nothing_res: String = "".to_string();
             // nth part
             for _i in 0..nothing {
@@ -2507,12 +2505,11 @@ impl fmt::Display for VectorLWE {
 
         if self.ciphertexts.as_tensor().len() <= 2 * n {
             for elt in self.ciphertexts.as_tensor().iter() {
-                to_be_print = to_be_print + &format!("{}, ", elt);
+                to_be_print = to_be_print + &format!("{}, ", *elt);
             }
-            to_be_print += "]\n";
         } else {
             for elt in self.ciphertexts.as_tensor().get_sub(0..n).iter() {
-                to_be_print = to_be_print + &format!("{}, ", elt);
+                to_be_print = to_be_print + &format!("{}, ", *elt);
             }
             to_be_print += "...";
 
@@ -2522,17 +2519,16 @@ impl fmt::Display for VectorLWE {
                 .get_sub(self.ciphertexts.as_tensor().len() - n..)
                 .iter()
             {
-                to_be_print = to_be_print + &format!("{}, ", elt);
+                to_be_print = to_be_print + &format!("{}, ", *elt);
             }
-            to_be_print += "]\n";
         }
+        to_be_print += "]\n";
 
         to_be_print += "         -> variances = [";
         if self.variances.len() <= 2 * n {
             for elt in self.variances.iter() {
                 to_be_print = to_be_print + &format!("{}, ", elt);
             }
-            to_be_print += "]\n";
         } else {
             for elt in self.variances[0..n].iter() {
                 to_be_print = to_be_print + &format!("{}, ", elt);
@@ -2541,8 +2537,8 @@ impl fmt::Display for VectorLWE {
             for elt in self.variances[self.variances.len() - n..].iter() {
                 to_be_print = to_be_print + &format!("{}, ", elt);
             }
-            to_be_print += "]\n";
         }
+        to_be_print += "]\n";
         to_be_print = to_be_print + &format!("         -> dimension = {}\n", self.dimension);
         to_be_print =
             to_be_print + &format!("         -> nb of ciphertexts = {}\n", self.nb_ciphertexts);
